==> rizin-0.4.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/rz_reg/rz_regConfig.cmake <==
################################################################################
#
# This module provides the following imported targets, if found:
#
#  rz_reg::rz_reg
#
# This file is intended to be consumed by clients who wish to use rz_reg from CMake.
# The recommended way to use find this module is using `find_package(Rizin COMPONENTS ...)`.
#
# Provides the following variables
# rz_reg_FOUND        - Flag for indicating that rz_reg package has been found
# rz_reg_VERSION      - Version of rz_reg
# rz_reg_INCLUDE_DIRS - Directories to include
# rz_reg_LIBRARY      - Path to the single library that this module represents, without dependencies
# rz_reg_LIBRARIES    - Libraries to link
# rz_reg_LIBRARY_DIRS - Library directories to search for link libraries
# rz_reg_PLUGINDIR    - Directory where plugins are placed, without the prefix part
#
################################################################################

set(RIZIN_MODULE_PREFIXED rz_reg)
set(rz_reg_VERSION 0.4.0)

# FIXME: workaround for https://github.com/mesonbuild/meson/issues/9702 (see https://github.com/rizinorg/rizin/issues/2102)
get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../.." ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

set(rz_reg_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include/librz" "${PACKAGE_PREFIX_DIR}/include/librz/sdb")
set_and_check(rz_reg_LIBRARY_DIRS "${PACKAGE_PREFIX_DIR}/lib")
find_library(rz_reg_LIBRARY NAMES rz_reg HINTS "${rz_reg_LIBRARY_DIRS}" NO_DEFAULT_PATH REQUIRED)
set(rz_reg_LIBRARIES "${rz_reg_LIBRARY}")
set(_rz_reg_DEPENDENCIES rz_util)
set(rz_reg_PLUGINDIR lib/rizin/plugins)

include(CMakeFindDependencyMacro)
get_filename_component(_rizin_cmake_path "${CMAKE_CURRENT_LIST_DIR}/.." ABSOLUTE)
set(_rz_reg_DEPENDENCY_TARGETS)
foreach(_module_dep ${_rz_reg_DEPENDENCIES})
  if (NOT ${_module_dep}_FOUND)
    find_dependency(${_module_dep} PATHS ${_rizin_cmake_path})
  endif()

  if (NOT ${_module_dep}_FOUND)
    set(rz_reg_FOUND False)
    return()
  endif()

  list(APPEND rz_reg_INCLUDE_DIRS "${${_module_dep}_INCLUDE_DIRS}")
  list(APPEND rz_reg_LIBRARIES "${${_module_dep}_LIBRARIES}")
  list(APPEND _rz_reg_DEPENDENCY_TARGETS "${_module_dep}::${_module_dep}")
endforeach()

list(REMOVE_DUPLICATES rz_reg_INCLUDE_DIRS)
list(REMOVE_DUPLICATES rz_reg_LIBRARIES)

if(NOT TARGET rz_reg::rz_reg)
  add_library(rz_reg::rz_reg SHARED IMPORTED)
  target_link_libraries(rz_reg::rz_reg INTERFACE ${_rz_reg_DEPENDENCY_TARGETS})
  set_target_properties(rz_reg::rz_reg PROPERTIES
    INTERFACE_INCLUDE_DIRECTORIES "${rz_reg_INCLUDE_DIRS}")
  set_target_properties(rz_reg::rz_reg PROPERTIES
    IMPORTED_LOCATION "${rz_reg_LIBRARY}")
endif()
set(rz_reg_TARGET rz_reg::rz_reg)

==> rizin-0.5.1-1-aarch64.pkg.tar.xz: usr/lib/cmake/rz_reg/rz_regConfig.cmake <==
################################################################################
#
# This module provides the following imported targets, if found:
#
#  rz_reg::rz_reg
#
# This file is intended to be consumed by clients who wish to use rz_reg from CMake.
# The recommended way to use find this module is using `find_package(Rizin COMPONENTS ...)`.
#
# Provides the following variables
# rz_reg_FOUND        - Flag for indicating that rz_reg package has been found
# rz_reg_VERSION      - Version of rz_reg
# rz_reg_INCLUDE_DIRS - Directories to include
# rz_reg_LIBRARY      - Path to the single library that this module represents, without dependencies
# rz_reg_LIBRARIES    - Libraries to link
# rz_reg_LIBRARY_DIRS - Library directories to search for link libraries
# rz_reg_PLUGINDIR    - Directory where plugins are placed, without the prefix part
#
################################################################################

set(RIZIN_MODULE_PREFIXED rz_reg)
set(rz_reg_VERSION 0.5.1)

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../.." ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

set(rz_reg_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include/librz" "${PACKAGE_PREFIX_DIR}/include/librz/sdb")
set_and_check(rz_reg_LIBRARY_DIRS "${PACKAGE_PREFIX_DIR}/lib")
find_library(rz_reg_LIBRARY NAMES rz_reg HINTS "${rz_reg_LIBRARY_DIRS}" NO_DEFAULT_PATH REQUIRED)
set(rz_reg_LIBRARIES "${rz_reg_LIBRARY}")
set(_rz_reg_DEPENDENCIES rz_util)
set(rz_reg_PLUGINDIR lib/rizin/plugins)

include(CMakeFindDependencyMacro)
get_filename_component(_rizin_cmake_path "${CMAKE_CURRENT_LIST_DIR}/.." ABSOLUTE)
set(_rz_reg_DEPENDENCY_TARGETS)
foreach(_module_dep ${_rz_reg_DEPENDENCIES})
  if (NOT ${_module_dep}_FOUND)
    find_dependency(${_module_dep} PATHS ${_rizin_cmake_path} NO_DEFAULT_PATH)
  endif()

  if (NOT ${_module_dep}_FOUND)
    set(rz_reg_FOUND False)
    return()
  endif()

  list(APPEND rz_reg_INCLUDE_DIRS "${${_module_dep}_INCLUDE_DIRS}")
  list(APPEND rz_reg_LIBRARIES "${${_module_dep}_LIBRARIES}")
  list(APPEND _rz_reg_DEPENDENCY_TARGETS "${_module_dep}::${_module_dep}")
endforeach()

list(REMOVE_DUPLICATES rz_reg_INCLUDE_DIRS)
list(REMOVE_DUPLICATES rz_reg_LIBRARIES)

if(NOT TARGET rz_reg::rz_reg)
  add_library(rz_reg::rz_reg SHARED IMPORTED)
  target_link_libraries(rz_reg::rz_reg INTERFACE ${_rz_reg_DEPENDENCY_TARGETS})
  set_target_properties(rz_reg::rz_reg PROPERTIES
    INTERFACE_INCLUDE_DIRECTORIES "${rz_reg_INCLUDE_DIRS}")
  set_target_properties(rz_reg::rz_reg PROPERTIES
    IMPORTED_LOCATION "${rz_reg_LIBRARY}")
endif()
set(rz_reg_TARGET rz_reg::rz_reg)
